@@ -475,8 +475,8 @@ setup_dialog (GsmPropertiesDialog *dialog)
         GtkTargetList     *targetlist;
 
         gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                                GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-                                GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                "gtk-help", GTK_RESPONSE_HELP,
+                                "gtk-close", GTK_RESPONSE_CLOSE,
                                 NULL);
 
         dialog->priv->list_store = gtk_list_store_new (NUMBER_OF_COLUMNS,
@@ -733,7 +733,7 @@ gsm_properties_dialog_init (GsmPropertiesDialog *dialog)
         content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
         widget = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
                                                      "main-notebook"));
-        gtk_container_add (GTK_CONTAINER (content_area), widget);
+        gtk_box_pack_start (GTK_BOX (content_area), widget, TRUE, TRUE, 0);
 
         gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
